@@ -67,12 +67,12 @@ class PlacemarkLayout : public QObject
     /**
      * Destroys the place mark painter.
      */
-    ~PlacemarkLayout();
+    ~PlacemarkLayout() override;
 
     /**
      * @reimp
      */
-    QVector<VisiblePlacemark *> generateLayout( const ViewportParams *viewport );
+    QVector<VisiblePlacemark *> generateLayout(const ViewportParams *viewport , int tileLevel);
 
     /**
      * Returns a list of model indexes that are at position @p pos.
@@ -83,6 +83,8 @@ class PlacemarkLayout : public QObject
 
     QList<VisiblePlacemark *> visiblePlacemarks() const;
 
+    bool hasPlacemarkAt(const QPoint &pos);
+
  public Q_SLOTS:
     // earth
     void setShowPlaces( bool show );
@@ -114,14 +116,15 @@ class PlacemarkLayout : public QObject
     int maxLabelHeight() const;
 
     void styleReset();
+    void clearCache();
 
-    static QSet<TileId> visibleTiles( const ViewportParams *viewport );
+    QSet<TileId> visibleTiles( const ViewportParams *viewport, int tileLevel ) const;
     bool layoutPlacemark(const GeoDataPlacemark *placemark, const GeoDataCoordinates &coordinates, qreal x, qreal y, bool selected );
 
     /**
      * Returns the coordinates at which an icon should be drawn for the @p placemark.
      * @p ok is set to true if the coordinates are valid and should be used for drawing,
-     * it it set to false otherwise.
+     * it is set to false otherwise.
      */
     GeoDataCoordinates placemarkIconCoordinates( const GeoDataPlacemark *placemark ) const;
 
@@ -164,6 +167,7 @@ class PlacemarkLayout : public QObject
     int     m_maxLabelHeight;
     bool    m_styleResetRequested;
     const StyleBuilder* m_styleBuilder;
+    VisiblePlacemark* m_lastPlacemarkAt;
 };
 
 }
