@@ -38,7 +38,7 @@ class GeoDataLineStringPrivate : public GeoDataGeometryPrivate
     {
     }
 
-    ~GeoDataLineStringPrivate()
+    ~GeoDataLineStringPrivate() override
     {
         delete m_rangeCorrected;
     }
@@ -55,23 +55,13 @@ class GeoDataLineStringPrivate : public GeoDataGeometryPrivate
     }
 
 
-    virtual GeoDataGeometryPrivate* copy()
+    GeoDataGeometryPrivate *copy() const override
     { 
         GeoDataLineStringPrivate* copy = new GeoDataLineStringPrivate;
         *copy = *this;
         return copy;
     }
 
-    virtual const char* nodeType() const
-    {
-        return GeoDataTypes::GeoDataLineStringType;
-    }
-
-    virtual EnumGeometryId geometryId() const 
-    {
-        return GeoDataLineStringId;
-    }
-
     void toPoleCorrected( const GeoDataLineString & q, GeoDataLineString & poleCorrected ) const;
 
     void toDateLineCorrected( const GeoDataLineString & q,
