@@ -24,7 +24,7 @@ DGML_DEFINE_TAG_HANDLER(RenderOrder)
 GeoNode* DgmlRenderOrderTagHandler::parse(GeoParser& parser) const
 {
     // Check whether the tag is valid
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(dgmlTag_RenderOrder));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(dgmlTag_RenderOrder)));
 
     // Checking for parent item
     GeoStackItem parentItem = parser.parentElement();
