@@ -24,7 +24,7 @@ namespace kml
 class KmlwhenTagHandler : public GeoTagHandler
 {
 public:
-    virtual GeoNode* parse(GeoParser&) const;
+    GeoNode* parse(GeoParser&) const override;
 
     static QDateTime parse( const QString &dateTime );
 
