@@ -42,20 +42,20 @@ public:
     explicit AlternativeRoutesModel( QObject *parent = 0 );
 
     /** Destructor */
-    ~AlternativeRoutesModel();
+    ~AlternativeRoutesModel() override;
 
     // Model querying
 
     /** Overload of QAbstractListModel */
-    int rowCount ( const QModelIndex &parent = QModelIndex() ) const;
+    int rowCount ( const QModelIndex &parent = QModelIndex() ) const override;
 
     /** Overload of QAbstractListModel */
-    QVariant headerData ( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
+    QVariant headerData ( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const override;
 
     /** Overload of QAbstractListModel */
-    QVariant data ( const QModelIndex &index, int role = Qt::DisplayRole ) const;
+    QVariant data ( const QModelIndex &index, int role = Qt::DisplayRole ) const override;
 
-    GeoDataDocument* route( int index );
+    const GeoDataDocument *route(int index) const;
 
     // Model data filling
 
@@ -75,7 +75,7 @@ public:
     /** Remove all alternative routes from the model */
     void clear();
 
-    GeoDataDocument* currentRoute();
+    const GeoDataDocument *currentRoute() const;
 
     /** Returns the waypoints contained in the route as a linestring */
     static const GeoDataLineString* waypoints( const GeoDataDocument* document );
@@ -84,7 +84,7 @@ public Q_SLOTS:
     void setCurrentRoute( int index );
 
 Q_SIGNALS:
-    void currentRouteChanged( GeoDataDocument* newRoute );
+    void currentRouteChanged(const GeoDataDocument *newRoute);
     void currentRouteChanged( int index );
 
 private Q_SLOTS:
