@@ -25,12 +25,12 @@ QString CachePlugin::name() const
 
 QString CachePlugin::nameId() const
 {
-    return "Cache";
+    return QStringLiteral("Cache");
 }
 
 QString CachePlugin::version() const
 {
-    return "1.0";
+    return QStringLiteral("1.0");
 }
 
 QString CachePlugin::description() const
@@ -40,13 +40,13 @@ QString CachePlugin::description() const
 
 QString CachePlugin::copyrightYears() const
 {
-    return "2011";
+    return QStringLiteral("2011");
 }
 
-QList<PluginAuthor> CachePlugin::pluginAuthors() const
+QVector<PluginAuthor> CachePlugin::pluginAuthors() const
 {
-    return QList<PluginAuthor>()
-            << PluginAuthor( "Thibaut Gridel", "tgridel@free.fr" );
+    return QVector<PluginAuthor>()
+            << PluginAuthor(QStringLiteral("Thibaut Gridel"), QStringLiteral("tgridel@free.fr"));
 }
 
 QString CachePlugin::fileFormatDescription() const
@@ -56,7 +56,7 @@ QString CachePlugin::fileFormatDescription() const
 
 QStringList CachePlugin::fileExtensions() const
 {
-    return QStringList() << "cache";
+    return QStringList(QStringLiteral("cache"));
 }
 
 ParsingRunner* CachePlugin::newRunner() const
